@@ -6,7 +6,7 @@ BEGIN {
     use lib "$FindBin::Bin/../lib";
     use lib "$FindBin::Bin";
 }
-use Geo::Postcodes::JP::DB qw/make_database test_database/;
+use Geo::Postcodes::JP::DB qw/make_database/;
 use PostCodeFiles qw/$db_file/;
 
 my $postcode_file = "$FindBin::Bin/KEN_ALL.CSV";
@@ -21,7 +21,3 @@ make_database (
     postcode_file => $postcode_file,
     schema_file => $schema_file,
 );
-
-#test_database (
-#    $db_file,
-#);
